from .data_selects import upload_handler, upload_auxiliary_data, data_selector
from .plotting import single_result_plot, dataset_plot, base_conf_graph, figure_download_link
from .tables import model_table
from .filters import model_selection
from . import utils